import os
import shutil
from glob import glob
from PIL import Image

def replace_or_resize_image(file_path, replacement_image):
    with Image.open(file_path) as original_image:
        original_width, original_height = original_image.size
        original_ratio = original_width / original_height

    replacement_width, replacement_height = replacement_image.size
    replacement_ratio = replacement_width / replacement_height

    if abs(original_ratio - replacement_ratio) > 1e-6:  # Allow for floating-point tolerance
        resized_image = replacement_image.resize((original_width, original_height))
        resized_image.save(file_path)
    else:
        shutil.copy2(replacement_image.filename, file_path)

def replace_images_in_folders(folder_patterns, replacement_image_path):
    replacement_image = Image.open(replacement_image_path)
    for pattern in folder_patterns:
        for path in glob(pattern):
            if os.path.isfile(path) and path.lower().endswith(('png', 'jpg', 'jpeg', 'bmp', 'gif')):
                replace_or_resize_image(path, replacement_image)
            elif os.path.isdir(path):
                for filename in os.listdir(path):
                    file_path = os.path.join(path, filename)
                    if os.path.isfile(file_path) and filename.lower().endswith(('png', 'jpg', 'jpeg', 'bmp', 'gif')):
                        replace_or_resize_image(file_path, replacement_image)

# Usage
replace_images_in_folders(['textures/*'], 'origin.png')
